STM L031K6-Nucleo board support
This crate provides convenience methods for working with the L031K6-Nucleo development board, and is intended to serve as a kind of example for how a board support crate might work. Under the hood, it ties pin function together with peripheral instantiation. Peripherals take as arguments, and subsequently own, the pins they’re attached to. This speeds development considerably, and reduces a lot of boilerplate setup code.
You can find a basic working example in [main.rs].
Re-exports
pub extern crate stm32l0x1_hal as hal;
Structs
Functions
- init
- Initialize the MCU and the board
Type Aliases
- Led
- A configured user LED